@@ -22,6 +22,7 @@ from dlk.managers import manager_register, manager_config_register
 from dlk.core.imodels import imodel_register, imodel_config_register
 import pickle as pkl
 import torch
+import copy
 import uuid
 import json
 from dlk.utils.logger import Logger
@@ -114,7 +115,7 @@ class Predict(object):
             None
 
         """
-        config = self.config['root']
+        config = copy.deepcopy(self.config['root'])
         name = self.name_str
         # get data
         if not data:
